@@ -23,7 +23,6 @@ import gedit
 import gtksourceview2 as gsv
 import gtk
 import glib
-import re
 
 from signals import Signals
 import constants
@@ -49,8 +48,6 @@ class DocumentHelper(Signals):
         self._buffer = None
         self._in_mode = False
         self._column_mode = None
-        self._move_cursor = None
-        self._previous_move_cursor = None
 
         self._edit_points = []
         self._multi_edited = False
@@ -65,17 +62,8 @@ class DocumentHelper(Signals):
         self.connect_signal(self._view, 'undo', self.on_view_undo)
         self.connect_signal(self._view, 'copy-clipboard', self.on_copy_clipboard)
         self.connect_signal(self._view, 'cut-clipboard', self.on_cut_clipboard)
-        self.connect_signal(self._view, 'paste-clipboard', self.on_paste_clipboard)
         self.connect_signal(self._view, 'query-tooltip', self.on_query_tooltip)
-
-        self.connect_signal(self._view, 'move-cursor', self.on_move_cursor)
-        self.connect_signal_after(self._view, 'move-cursor', self.on_move_cursor_after)
-
-        try:
-            self.connect_signal(self._view, 'smart-home-end', self.on_smart_home_end)
-        except:
-            pass
-
+        
         self._view.props.has_tooltip = True
 
         self.reset_buffer(self._view.get_buffer())
@@ -139,11 +127,11 @@ class DocumentHelper(Signals):
 
         self.disconnect_signals(self._view)
         self._view = None
-
+        
         if self._status_timeout != 0:
             glib.source_remove(self._status_timeout)
             self._status_timeout = 0
-
+        
         if self._delete_mode_id != 0:
             glib.source_remove(self._delete_mode_id)
             self._delete_mode_id = 0
@@ -152,9 +140,6 @@ class DocumentHelper(Signals):
         self._event_handlers = [
             [('Escape',), 0, self.do_escape_mode, True],
             [('Return',), 0, self.do_column_edit, True],
-            [('Return',), gtk.gdk.CONTROL_MASK, self.do_smart_column_edit, True],
-            [('Return',), gtk.gdk.CONTROL_MASK | gtk.gdk.SHIFT_MASK, self.do_smart_column_align, True],
-            [('Return',), gtk.gdk.CONTROL_MASK | gtk.gdk.SHIFT_MASK | gtk.gdk.MOD1_MASK, self.do_smart_column_align, True],
             [('Home',), gtk.gdk.CONTROL_MASK, self.do_mark_start, True],
             [('End',), gtk.gdk.CONTROL_MASK, self.do_mark_end, True],
             [('e',), gtk.gdk.CONTROL_MASK, self.do_toggle_edit_point, True]
@@ -214,7 +199,21 @@ class DocumentHelper(Signals):
         return True
 
     def iter_to_offset(self, piter):
-        return self._view.get_visual_column(piter)
+        tw = self._view.get_tab_width()
+        start = piter.copy()
+        start.set_line_offset(0)
+
+        offset = 0
+
+        while not start.equal(piter):
+            if start.get_char() == "\t":
+                offset += tw - (offset % tw)
+            else:
+                offset += 1
+
+            start.forward_char()
+
+        return offset
 
     def get_visible_iter(self, line, offset):
         piter = self._buffer.get_iter_at_line(line)
@@ -288,11 +287,11 @@ class DocumentHelper(Signals):
     def _add_edit_point(self, piter):
         # Check if there is already an edit point here
         marks = piter.get_marks()
-
+        
         for mark in marks:
             if mark in self._edit_points:
                 return
-
+        
         buf = self._buffer
         mark = buf.create_mark(None, piter, True)
         mark.set_visible(True)
@@ -302,7 +301,7 @@ class DocumentHelper(Signals):
 
     def _remove_duplicate_edit_points(self):
         buf = self._buffer
-
+        
         for mark in list(self._edit_points):
             if mark.get_deleted():
                 continue
@@ -311,14 +310,14 @@ class DocumentHelper(Signals):
 
             others = piter.get_marks()
             others.remove(mark)
-
+            
             for other in others:
                 if other in self._edit_points:
                     buf.delete_mark(other)
                     self._edit_points.remove(other)
-
+        
         marks = buf.get_iter_at_mark(buf.get_insert()).get_marks()
-
+        
         for mark in marks:
             if mark in self._edit_points:
                 buf.delete_mark(mark)
@@ -335,7 +334,7 @@ class DocumentHelper(Signals):
     def _remove_status(self):
         self._status = None
         self._invalidate_status()
-
+        
         self._status_timeout = 0
         return False
 
@@ -343,13 +342,13 @@ class DocumentHelper(Signals):
         if not self._in_mode:
             self._status = None
             return
-
+            
         self._status = text
         self._invalidate_status()
-
+        
         if self._status_timeout != 0:
             glib.source_remove(self._status_timeout)
-
+        
         self._status_timeout = glib.timeout_add(3000, self._remove_status)
 
     def _apply_column_mode(self):
@@ -392,200 +391,6 @@ class DocumentHelper(Signals):
         if start.compare(end) < 0:
             self._buffer.apply_tag(self._selection_tag, start, end)
 
-    def smart_column_iters(self):
-        buf = self._buffer
-
-        bounds = buf.get_selection_bounds()
-
-        if not bounds or bounds[0].get_line() == bounds[1].get_line():
-            return False
-
-        # There are a few 'smart' things
-        # 1) if there is a number at the cursor, match any number
-        # 2) if there is a non-alpha/non-space at the cursor, match it
-        # 3) match word position
-        mm = buf.get_iter_at_mark(buf.get_selection_bound())
-
-        ch = mm.get_char()
-        insline = mm.get_line()
-
-        regex = None
-
-        if ch.isnumeric():
-            regex = re.compile('[0-9]')
-        elif not ch.isalpha() and not ch.isspace():
-            regex = re.compile(re.escape(ch))
-        elif not mm.starts_word():
-            return True
-
-        start = bounds[0].copy()
-        end = bounds[1].copy()
-
-        offset = self.iter_to_offset(mm)
-
-        if not regex:
-            # Get word number
-            worditer = mm.copy()
-
-            if not worditer.starts_line():
-                worditer.set_line_offset(0)
-
-            wordcount = 0
-
-            while worditer.compare(start) < 0:
-                if not worditer.forward_visible_word_end():
-                    break
-
-                wordcount += 1
-
-        if not start.starts_line():
-            start.set_line_offset(0)
-
-        iters = []
-
-        while start.compare(end) < 0:
-            if start.get_line() != insline:
-                lineend = start.copy()
-
-                if not lineend.ends_line():
-                    lineend.forward_to_line_end()
-
-                if regex:
-                    matches = regex.finditer(start.get_text(lineend))
-                    closest = None
-                    closest_diff = 0
-
-                    for match in matches:
-                        piter = start.copy()
-                        piter.forward_chars(match.start(0))
-
-                        diff = abs(self.iter_to_offset(piter) - offset)
-
-                        if not closest or diff < closest_diff:
-                            closest = piter
-                            closest_diff = diff
-
-                    if not matches:
-                        return True
-                else:
-                    lineno = start.get_line()
-                    cp = start.copy()
-                    cnt = 0
-
-                    if wordcount > 0 and cp.forward_visible_word_ends(wordcount):
-                        if cp.backward_visible_word_start() and cp.get_line() == lineno:
-                            closest = cp
-                        else:
-                            closest = start.copy()
-
-                            if not closest.ends_line():
-                                closest.forward_to_line_end()
-
-                iters.append(closest)
-            else:
-                iters.append(mm)
-
-            if not start.forward_line():
-                break
-
-        return iters
-
-    def do_smart_column_align(self, event):
-        if not self._edit_points:
-            ret = self.smart_column_iters()
-
-            if ret == True or ret == False:
-                return ret
-        else:
-            iters = [self._buffer.get_iter_at_mark(x) for x in self._edit_points]
-            iters.append(self._buffer.get_iter_at_mark(self._buffer.get_insert()))
-
-            iters.sort(lambda a, b: a.compare(b))
-            ret = []
-            lastline = -1
-
-            for piter in iters:
-                line = piter.get_line()
-
-                if line != lastline:
-                    ret.append(piter)
-
-                lastline = line
-
-        lastline = self._buffer.get_iter_at_mark(self._buffer.get_insert()).get_line()
-
-        # Get max visual offset
-        offsets = []
-        maxoffset = 0
-
-        for piter in ret:
-            offset = self.iter_to_offset(piter)
-
-            cp = piter.copy()
-            moffset = offset
-
-            if (event.state & gtk.gdk.MOD1_MASK) and cp.backward_visible_cursor_position() and not cp.get_char().isspace():
-                moffset += 1
-
-            if moffset > maxoffset:
-                maxoffset = moffset
-
-            offsets.append(offset)
-
-        marks = [self._buffer.create_mark(None, x, False) for x in ret]
-
-        # Remove previous edit points
-        self.remove_edit_points()
-
-        self.block_signal(self._buffer, 'mark-set')
-        self.block_signal(self._buffer, 'insert-text')
-
-        self._buffer.begin_user_action()
-
-        for i in range(len(marks)):
-            # Align with spaces on the left such that 'mark' is at maxoffset
-            num = maxoffset - offsets[i]
-            text = ' ' * num
-
-            piter = self._buffer.get_iter_at_mark(marks[i])
-            self._buffer.insert(piter, text)
-
-            if piter.get_line() != lastline:
-                self._add_edit_point(piter)
-            else:
-                self._buffer.place_cursor(piter)
-
-        for mark in marks:
-            self._buffer.delete_mark(mark)
-
-        self._buffer.end_user_action()
-
-        self.unblock_signal(self._buffer, 'mark-set')
-        self.unblock_signal(self._buffer, 'insert-text')
-
-        return True
-
-    def do_smart_column_edit(self, event):
-        ret = self.smart_column_iters()
-
-        if ret == True or ret == False:
-            return ret
-
-        lastline = self._buffer.get_iter_at_mark(self._buffer.get_insert()).get_line()
-
-        # Remove previous edit points
-        self.remove_edit_points()
-
-        for i in range(len(ret)):
-            piter = ret[i]
-
-            if piter.get_line() != lastline:
-                self._add_edit_point(piter)
-            else:
-                self._buffer.place_cursor(piter)
-
-        return True
-
     def do_column_edit(self, event):
         buf = self._buffer
 
@@ -609,26 +414,22 @@ class DocumentHelper(Signals):
         if eoff < soff:
             tmp = soff
             soff = eoff
-            eoff = tmp
+            eoff = soff
 
         # Apply tags where possible
         start_line = start.get_line()
         end_line = end.get_line()
 
-        singlecolumn = soff == eoff
-
         while start.get_line() <= end.get_line():
             self.line_column_edit(start, soff, eoff)
 
-            singlecolumn = (singlecolumn and self.get_visible_iter(start.get_line(), soff)[1] == 0)
-
             if not start.forward_line():
                 break
 
         # Remove official selection
         insert = buf.get_iter_at_mark(buf.get_insert())
         buf.move_mark(buf.get_selection_bound(), insert)
-
+        
         # Remove previous marks
         self.remove_edit_points()
 
@@ -636,10 +437,6 @@ class DocumentHelper(Signals):
         self._column_mode = (start_line, end_line, soff, eoff)
         self.status('<i>%s</i>' % (xml.sax.saxutils.escape(_('Column Mode...')),))
 
-        if singlecolumn:
-            self._apply_column_mode()
-            self._multi_edited = True
-
         return True
 
     def _draw_column_mode(self, event):
@@ -692,7 +489,7 @@ class DocumentHelper(Signals):
 
             ctx.rectangle(rx, y, rw, height)
             ctx.fill()
-
+            
         return False
 
     def do_mark_start_end(self, test, move):
@@ -717,51 +514,51 @@ class DocumentHelper(Signals):
 
             if not start.forward_line():
                 break
-
+        
         return orig, end
 
     def do_mark_start(self, event):
         start, end = self.do_mark_start_end(None, lambda x: x.set_line_offset(0))
-
+        
         start.backward_line()
-
+        
         buf = self._buffer
         buf.move_mark(buf.get_insert(), start)
         buf.move_mark(buf.get_selection_bound(), start)
-
+        
         return True
 
     def do_mark_end(self, event):
         start, end = self.do_mark_start_end(lambda x: x.ends_line(), lambda x: x.forward_to_line_end())
-
+        
         end.forward_line()
-
+        
         if not end.ends_line():
             end.forward_to_line_end()
-
+        
         buf = self._buffer
         buf.move_mark(buf.get_insert(), end)
         buf.move_mark(buf.get_selection_bound(), end)
 
         return True
-
+        
     def do_toggle_edit_point(self, event):
         buf = self._buffer
         piter = buf.get_iter_at_mark(buf.get_insert())
-
+        
         marks = piter.get_marks()
-
+        
         for mark in marks:
             if mark in self._edit_points:
                 buf.delete_mark(mark)
                 self._edit_points.remove(mark)
-
+                
                 self.status('<i>%s</i>' % (xml.sax.saxutils.escape(_('Removed edit point...'),)))
                 return
-
+        
         self._add_edit_point(piter)
         return True
-
+        
     def on_key_press_event(self, view, event):
         defmod = gtk.accelerator_get_default_mod_mask() & event.state
 
@@ -800,7 +597,7 @@ class DocumentHelper(Signals):
             # Insert the text at all the edit points
             for mark in self._edit_points:
                 piter = buf.get_iter_at_mark(mark)
-
+                
                 if not buf.get_iter_at_mark(buf.get_insert()).equal(piter):
                     self._multi_edited = True
                     buf.insert(piter, text)
@@ -811,11 +608,11 @@ class DocumentHelper(Signals):
 
         if hasattr(where, 'assign'):
             where.assign(iterwas)
-
+        
         if atinsert:
             buf.move_mark(buf.get_insert(), iterwas)
             buf.move_mark(buf.get_selection_bound(), iterwas)
-
+            
         buf.delete_mark(wasat)
         buf.end_user_action()
         self.unblock_signal(buf, 'insert-text')
@@ -834,33 +631,20 @@ class DocumentHelper(Signals):
     def handle_column_mode_delete(self, mark):
         buf = self._buffer
         start = buf.get_iter_at_mark(mark)
+        buf.delete_mark(mark)
 
         self._view.set_editable(True)
 
         # Reinsert what was deleted, and apply column mode
         self.block_signal(buf, 'insert-text')
 
-        singlecolumn = self._column_mode[2] == self._column_mode[3]
-
         buf.begin_user_action()
         buf.insert(start, self._delete_text)
-
-        start = buf.get_iter_at_mark(mark)
-        buf.delete_mark(mark)
-
         self._apply_column_mode()
         buf.end_user_action()
 
         self.unblock_signal(buf, 'insert-text')
         self._delete_mode_id = 0
-
-        if singlecolumn:
-            # Redo the delete actually
-            end = start.copy()
-            end.forward_char()
-
-            buf.delete(start, end)
-
         return False
 
     def on_delete_range(self, buf, start, end):
@@ -878,7 +662,7 @@ class DocumentHelper(Signals):
                 for mark in self._edit_points:
                     piter = buf.get_iter_at_mark(mark)
                     other = piter.copy()
-
+                    
                     if self._is_backspace:
                         # Remove 'delete_length' chars _before_ piter
                         if not other.backward_chars(self._delete_length):
@@ -897,10 +681,10 @@ class DocumentHelper(Signals):
 
                 buf.end_user_action()
                 self.unblock_signal(buf, 'delete-range')
-
+                
                 piter = buf.get_iter_at_mark(orig)
                 buf.delete_mark(orig)
-
+                
                 # To be able to have it not crash with old pygtk
                 if hasattr(start, 'assign'):
                     start.assign(piter)
@@ -918,28 +702,28 @@ class DocumentHelper(Signals):
         bounds = buf.get_bounds()
 
         buf.remove_tag(self._selection_tag, bounds[0], bounds[1])
-
+        
         self.status('<i>%s</i>' % (xml.sax.saxutils.escape(_('Cancelled column mode...'),)))
         self._view.queue_draw()
 
     def _column_text(self):
         if not self._column_mode:
             return ''
-
+        
         start = self._column_mode[0]
         end = self._column_mode[1]
         buf = self._buffer
 
         cstart = self._column_mode[2]
         cend = self._column_mode[3]
-
+        
         lines = []
         width = cend - cstart
 
         while start <= end:
             start_iter, soff = self.get_visible_iter(start, cstart)
             end_iter, eoff = self.get_visible_iter(start, cend)
-
+            
             if soff == 0 and eoff == 0:
                 # Just text
                 lines.append(start_iter.get_text(end_iter))
@@ -958,243 +742,34 @@ class DocumentHelper(Signals):
                 lines.append(start_iter.get_text(end_iter) + (' ' * abs(eoff)))
             else:
                 lines.append('')
-
+            
             start += 1
-
+        
         return "\n".join(lines)
 
     def on_copy_clipboard(self, view):
         if not self._column_mode:
             return
-
+        
         text = self._column_text()
 
         clipboard = gtk.Clipboard(self._view.get_display())
         clipboard.set_text(text)
-
+        
         view.stop_emission('copy-clipboard')
-
+    
     def on_cut_clipboard(self, view):
         if not self._column_mode:
             return
-
+        
         text = self._column_text()
         clipboard = gtk.Clipboard(self._view.get_display())
         clipboard.set_text(text)
-
+        
         view.stop_emission('cut-clipboard')
-
+        
         self._apply_column_mode()
 
-    def on_clipboard_text(self, clipboard, text, data):
-        # Check if the number of lines in the text matches the number of edit
-        # points
-
-        lines = []
-
-        if text:
-            lines = text.splitlines()
-
-        buf = self._buffer
-        piter = buf.get_iter_at_mark(self._paste_mark)
-        ins = buf.get_iter_at_mark(buf.get_insert())
-
-        if len(lines) != (len(self._edit_points) + 1) or piter.compare(ins) != 0:
-            # Actually, the buffer better handle it...
-            self.block_signal(self._view, 'paste-clipboard')
-            buf.paste_clipboard(clipboard, piter, True)
-            self.unblock_signal(self._view, 'paste-clipboard')
-        else:
-            # Insert text at each of the edit points then
-            self.block_signal(buf, 'insert-text')
-            self.block_signal(self._view, 'mark-set')
-
-            buf.begin_user_action()
-
-            marks = list(self._edit_points)
-            marks.append(buf.get_insert())
-
-            marks.sort(lambda a, b: buf.get_iter_at_mark(a).compare(buf.get_iter_at_mark(b)))
-
-            for i in range(len(lines)):
-                piter = buf.get_iter_at_mark(marks[i])
-                buf.insert(piter, lines[i])
-
-                if marks[i] != buf.get_insert():
-                    buf.move_mark(marks[i], piter)
-
-            buf.end_user_action()
-
-            self.unblock_signal(buf, 'insert-text')
-            self.unblock_signal(self._view, 'mark-set')
-
-        buf.delete_mark(self._paste_mark)
-
-    def on_paste_clipboard(self, view):
-        if not self._edit_points:
-            return
-
-        clipboard = gtk.Clipboard(self._view.get_display())
-        self._paste_mark = self._buffer.create_mark(None, self._buffer.get_iter_at_mark(self._buffer.get_insert()), True)
-
-        clipboard.request_text(self.on_clipboard_text)
-        view.stop_emission('paste-clipboard')
-
-    def _move_edit_points(self, buf, where):
-        diff = where.get_offset() - buf.get_iter_at_mark(self._last_insert).get_offset()
-
-        for point in self._edit_points:
-            piter = buf.get_iter_at_mark(point)
-            piter.set_offset(piter.get_offset() + diff)
-            buf.move_mark(point, piter)
-
-    def _move_edit_point_logical_positions(self, piter, count):
-        piter.forward_cursor_positions(count)
-
-        return piter
-
-    def _move_edit_point_visual_positions(self, piter, count):
-        self._view.move_visually(piter, count)
-
-        return piter
-
-    def _move_edit_point_words(self, piter, count):
-        if count > 0:
-            piter.forward_visible_word_ends(count)
-        else:
-            piter.backward_visible_word_starts(-count)
-
-        return piter
-
-    def _move_edit_point_display_lines(self, piter, count):
-        offset = self.iter_to_offset(piter)
-
-        if count < 0:
-            cnt = -count
-        else:
-            cnt = count
-
-        for i in xrange(cnt):
-            if count > 0:
-                self._view.forward_display_line(piter)
-            else:
-                self._view.backward_display_line(piter)
-
-        piter, off = self.get_visible_iter(piter.get_line(), offset)
-
-        return piter
-
-    def _move_to_first_char(self, piter, display_line):
-        last = piter.copy()
-
-        if display_line:
-            self._view.forward_display_line_end(last)
-            self._view.backward_display_line_start(piter)
-        else:
-            piter.set_line_offset(0)
-
-            if not last.ends_line():
-                last.forward_to_line_end()
-
-        while piter.compare(last) < 0:
-            if piter.get_char().isspace():
-                piter.forward_visible_cursor_position()
-            else:
-                break
-
-    def _move_to_last_char(self, piter, display_line):
-        first = piter.copy()
-
-        if display_line:
-            self._view.backward_display_line_start(first)
-            self._view.forward_display_line_end(piter)
-        else:
-            if not piter.ends_line():
-                piter.forward_to_line_end()
-
-            first.set_line_offset(0)
-
-        while piter.compare(first) > 0:
-            piter.backward_visible_cursor_position()
-
-            if not piter.get_char().isspace():
-                if not piter.forward_visible_cursor_position():
-                    piter.forward_to_end()
-
-                break
-
-    def _move_edit_point_smart_display_line_ends(self, piter, count):
-        if count > 0:
-            self._move_to_last_char(piter, True)
-        else:
-            self._move_to_first_char(piter, True)
-
-        return piter
-
-    def _move_edit_point_display_line_ends(self, piter, count):
-        if count > 0:
-            self._view.forward_display_line_end(piter)
-        else:
-            self._view.backward_display_line_start(piter)
-
-        return piter
-
-    def _move_edit_point_paragraphs(self, piter, count):
-        offset = self.iter_to_offset(piter)
-
-        piter.forward_visible_lines(count)
-        piter, off = self.get_visible_iter(piter.get_line(), offset)
-
-        return piter
-
-    def _move_edit_point_smart_paragraph_ends(self, piter, count):
-        if count > 0:
-            self._move_to_last_char(piter, False)
-        else:
-            self._move_to_first_char(piter, False)
-
-        return piter
-
-    def _move_edit_point_paragraph_ends(self, piter, count):
-        if count > 0:
-            if not piter.ends_line():
-                piter.forward_to_line_end()
-        elif not piter.starts_line():
-            piter.set_line_offset(0)
-
-        return piter
-
-    def _move_edit_point_horizontal_pages(self, piter, count):
-        return self._move_edit_point_paragraph_ends(piter, count)
-
-    def _move_edit_points_by_cursor(self, buf, where):
-        actions = {
-            gtk.MOVEMENT_LOGICAL_POSITIONS: self._move_edit_point_logical_positions,
-            gtk.MOVEMENT_VISUAL_POSITIONS: self._move_edit_point_visual_positions,
-            gtk.MOVEMENT_WORDS: self._move_edit_point_words,
-            gtk.MOVEMENT_DISPLAY_LINES: self._move_edit_point_display_lines,
-            gtk.MOVEMENT_DISPLAY_LINE_ENDS: self._move_edit_point_display_line_ends,
-            gtk.MOVEMENT_PARAGRAPHS: self._move_edit_point_paragraphs,
-            gtk.MOVEMENT_PARAGRAPH_ENDS: self._move_edit_point_paragraph_ends,
-            gtk.MOVEMENT_HORIZONTAL_PAGES: self._move_edit_point_horizontal_pages,
-        }
-
-        typ = self._move_cursor[0]
-        count = self._move_cursor[1]
-
-        if not typ in actions:
-            return self._move_edit_points(buf, where)
-
-        action = actions[typ]
-
-        for point in self._edit_points:
-            piter = buf.get_iter_at_mark(point)
-            piter = action(piter, count)
-            buf.move_mark(point, piter)
-
-        self._previous_move_cursor = self._move_cursor
-        self._move_cursor = None
-
     def on_mark_set(self, buf, where, mark):
         if not mark == buf.get_insert():
             return
@@ -1204,10 +779,14 @@ class DocumentHelper(Signals):
                 # Cancel column mode when cursor moves
                 self._cancel_column_mode()
             elif self._edit_points and self._multi_edited:
-                if self._move_cursor != None:
-                    self._move_edit_points_by_cursor(buf, where)
-                else:
-                    self._move_edit_points(buf, where)
+                # Detect moving up or down a line
+                
+                diff = where.get_offset() - buf.get_iter_at_mark(self._last_insert).get_offset()
+
+                for point in self._edit_points:
+                    piter = buf.get_iter_at_mark(point)
+                    piter.set_offset(piter.get_offset() + diff)
+                    buf.move_mark(point, piter)
 
                 self._remove_duplicate_edit_points()
 
@@ -1216,58 +795,38 @@ class DocumentHelper(Signals):
     def on_view_undo(self, view):
         self._cancel_column_mode()
         self.remove_edit_points()
-
-    def make_label(self, text, use_markup=True):
+    
+    def make_label(self, text):
         lbl = gtk.Label(text)
-        lbl.set_use_markup(use_markup)
         lbl.set_alignment(0, 0.5)
         lbl.show()
-
+        
         return lbl
-
+    
     def on_query_tooltip(self, view, x, y, keyboard_mode, tooltip):
         if not self._in_mode:
             return False
-
-        geom = view.get_window(gtk.TEXT_WINDOW_TOP).get_geometry()
-
-        if x < geom[0] or x > geom[0] + geom[2] or y < geom[1] or y > geom[1] + geom[3]:
+        
+        geom = view.get_window(gtk.TEXT_WINDOW_TEXT).get_geometry()
+        geom2 = view.get_window(gtk.TEXT_WINDOW_LEFT).get_geometry()
+        
+        if y < geom[3] or x < geom2[2]:
             return False
 
-        table = gtk.Table(13, 2)
+        table = gtk.Table(4, 2)
         table.set_row_spacings(3)
-        table.set_col_spacings(12)
-
-        table.attach(self.make_label('<b>Selection</b>', True), 0, 2, 0, 1, gtk.SHRINK | gtk.FILL, gtk.SHRINK | gtk.FILL)
-
-        table.attach(self.make_label('<Enter>', False), 0, 1, 1, 2, gtk.SHRINK | gtk.FILL, gtk.SHRINK | gtk.FILL)
-        table.attach(self.make_label('<Ctrl><Enter>', False), 0, 1, 2, 3, gtk.SHRINK | gtk.FILL, gtk.SHRINK | gtk.FILL)
-        table.attach(self.make_label('<Ctrl><Shift><Enter>', False), 0, 1, 3, 4, gtk.SHRINK | gtk.FILL, gtk.SHRINK | gtk.FILL)
-        table.attach(self.make_label('<Ctrl><Alt><Shift><Enter>', False), 0, 1, 4, 5, gtk.SHRINK | gtk.FILL, gtk.SHRINK | gtk.FILL)
-
-        sep = gtk.HSeparator()
-        sep.show()
-
-        table.attach(sep, 0, 2, 5, 6, gtk.SHRINK | gtk.FILL, gtk.SHRINK | gtk.FILL)
-
-        table.attach(self.make_label('<b>Edit points</b>', True), 0, 2, 6, 7, gtk.SHRINK | gtk.FILL, gtk.SHRINK | gtk.FILL)
-        table.attach(self.make_label('<Ctrl>+E', False), 0, 1, 7, 8, gtk.SHRINK | gtk.FILL, gtk.SHRINK | gtk.FILL)
-        table.attach(self.make_label('<Ctrl><Home>', False), 0, 1, 8, 9, gtk.SHRINK | gtk.FILL, gtk.SHRINK | gtk.FILL)
-        table.attach(self.make_label('<Ctrl><End>', False), 0, 1, 9, 10, gtk.SHRINK | gtk.FILL, gtk.SHRINK | gtk.FILL)
-        table.attach(self.make_label('<Ctrl><Shift><Enter>', False), 0, 1, 10, 11, gtk.SHRINK | gtk.FILL, gtk.SHRINK | gtk.FILL)
-        table.attach(self.make_label('<Ctrl><Alt><Shift><Enter>', False), 0, 1, 11, 12, gtk.SHRINK | gtk.FILL, gtk.SHRINK | gtk.FILL)
-
-        table.attach(self.make_label(_('Enter column edit mode using selection')), 1, 2, 1, 2)
-        table.attach(self.make_label(_('Enter <b>smart</b> column edit mode using selection')), 1, 2, 2, 3)
-        table.attach(self.make_label(_('<b>Smart</b> column align mode using selection')), 1, 2, 3, 4)
-        table.attach(self.make_label(_('<b>Smart</b> column align mode with additional space using selection')), 1, 2, 4, 5)
-
-        table.attach(self.make_label(_('Toggle edit point')), 1, 2, 7, 8)
-        table.attach(self.make_label(_('Add edit point at beginning of line/selection')), 1, 2, 8, 9)
-        table.attach(self.make_label(_('Add edit point at end of line/selection')), 1, 2, 9, 10)
-        table.attach(self.make_label(_('Align edit points')), 1, 2, 10, 11)
-        table.attach(self.make_label(_('Align edit points with additional space')), 1, 2, 11, 12)
+        table.set_col_spacings(6)
 
+        table.attach(self.make_label('<Enter>:'), 0, 1, 0, 1, gtk.SHRINK | gtk.FILL, gtk.SHRINK | gtk.FILL)
+        table.attach(self.make_label('<Ctrl>+E:'), 0, 1, 1, 2, gtk.SHRINK | gtk.FILL, gtk.SHRINK | gtk.FILL)
+        table.attach(self.make_label('<Ctrl><Home>:'), 0, 1, 2, 3, gtk.SHRINK | gtk.FILL, gtk.SHRINK | gtk.FILL)
+        table.attach(self.make_label('<Ctrl><End>:'), 0, 1, 3, 4, gtk.SHRINK | gtk.FILL, gtk.SHRINK | gtk.FILL)
+        
+        table.attach(self.make_label(_('Enter column edit mode using selection')), 1, 2, 0, 1)
+        table.attach(self.make_label(_('Toggle edit point')), 1, 2, 1, 2)
+        table.attach(self.make_label(_('Add edit point at beginning of line/selection')), 1, 2, 2, 3)
+        table.attach(self.make_label(_('Add edit point at end of line/selection')), 1, 2, 3, 4)
+        
         table.show_all()
         tooltip.set_custom(table)
         return True
@@ -1313,7 +872,7 @@ class DocumentHelper(Signals):
         ctx.set_line_width(1)
 
         col = self.from_color(view.get_style().text[view.state])
-
+        
         ctx.set_source_rgba(col[0], col[1], col[2], 0.6)
         ctx.move_to(geom[0], geom[1] + geom[3] - 1)
         ctx.rel_line_to(geom[2], 0)
@@ -1322,7 +881,7 @@ class DocumentHelper(Signals):
         ctx.set_source_rgb(col[0], col[1], col[2])
         ctx.move_to(geom[2] - extents[1][2] - 3, (geom[3] - extents[1][3]) / 2)
         ctx.show_layout(layout)
-
+        
         if not self._status:
             status = ''
         else:
@@ -1330,36 +889,10 @@ class DocumentHelper(Signals):
 
         if status:
             layout.set_markup(status)
-
+            
             ctx.move_to(3, (geom[3] - extents[1][3]) / 2)
             ctx.show_layout(layout)
 
         return False
 
-    def on_smart_home_end(self, view, iter, count):
-        if not self._in_mode or not self._edit_points or not self._previous_move_cursor:
-            return
-
-        ins = self._buffer.get_iter_at_mark(self._buffer.get_insert())
-
-        if not ins.equal(iter):
-            return
-
-        if self._previous_move_cursor[0] == gtk.MOVEMENT_DISPLAY_LINE_ENDS:
-            cb = self._move_edit_point_smart_display_line_ends
-        else:
-            cb = self._move_edit_point_smart_paragraph_ends
-
-        for point in self._edit_points:
-            piter = self._buffer.get_iter_at_mark(point)
-            piter = cb(piter, count)
-            self._buffer.move_mark(point, piter)
-
-    def on_move_cursor(self, view, step_size, count, extend_selection):
-        self._move_cursor = [step_size, count]
-
-    def on_move_cursor_after(self, view, step_size, count, extend_selection):
-        self._move_cursor = None
-        self._previous_move_cursor = None
-
 # ex:ts=4:et:
